import { useState, useEffect } from 'react';
import { getProfile, updateProfile } from '@/lib/actions';
import type { Profile } from '@/utils/supabase';
import { toast } from 'sonner';

export const useProfile = () => {
  const [profile, setProfile] = useState<Profile | undefined>(undefined);
  const [isLoading, setIsLoading] = useState(true);

  useEffect(() => {
    const fetchProfile = async () => {
      try {
        setIsLoading(true);
        const profileResponse = await getProfile();
        if (!profileResponse.success)
          throw new Error('Profile response unsuccessful');
        setProfile(profileResponse.data);
      } catch {
        setProfile(undefined);
      } finally {
        setIsLoading(false);
      }
    };
    fetchProfile().catch((error) => {
      toast.error(error instanceof Error ? error.message : 'Failed to get profile');
    });
  }, []);

  const updateUserProfile = async (data: {
    full_name?: string;
    email?: string;
    avatar_url?: string;
  }) => {
    try {
      setIsLoading(true);
      const result = await updateProfile(data);
      if (!result.success) {
        throw new Error(result.error ?? 'Failed to update profile');
      }
      setProfile(result.data);
      toast.success('Profile updated successfully!');
      return { success: true, data: result.data };
    } catch (error) {
      console.error('Error updating profile: ', error);
      toast.error(error instanceof Error ? error.message : 'Failed to update profile');
      return { success: false, error };
    } finally {
      setIsLoading(false);
    }
  };

  return {
    profile,
    isLoading,
    updateProfile: updateUserProfile,
  };
}
